@@ -1,4 +1,5 @@
 from django.db import models
+from django.core.validators import MaxLengthValidator
 
 from transmeta import TransMeta
 
@@ -30,7 +31,7 @@ class Sponsor(models.Model):
     __metaclass__ = TransMeta
 
     name = models.CharField(max_length=100)
-    description = models.TextField(max_length=255)
+    description = models.TextField(validators=[MaxLengthValidator(1000)])
     url = models.URLField()
     category = models.ForeignKey(Category)
     logo = models.ImageField(upload_to='sponsors')
